edit method

OrgZipper edit()

Obtain a zipper starting at the root of this node. The zipper can be used to edit the node; call ZipperLocation.commit to obtain a new node with the edits applied.

Implementation

OrgZipper edit() => ZipperLocation.root(
      sectionP: (obj) => obj is OrgParentNode,
      node: this,
      getChildren: (obj) => obj.children,
      makeSection: (node, children) => node.fromChildren(children),
    );