editNode method

OrgZipper? editNode(
  1. OrgNode node
)

Obtain a zipper for the specified node, which is presumed to be a descendant of this node. Returns null if the node is not found. The zipper can be used to edit this node; call ZipperLocation.commit to obtain a new node with the edits applied.

Implementation

OrgZipper? editNode(OrgNode node) => edit().find(node);